
From: Kronos <kronos@kronoz.cjb.net>


Teach fb to use class_simple.  With this patch udev will automagically
create device nodes for each framebuffer registered.  Once all drivers are
converted to framebuffer_{alloc,release} we can switch to our own class.

This is what sysfs dir looks like:

notebook:~# tree /sys/class/graphics/
/sys/class/graphics/
`-- fb0
    `-- dev



---

 25-akpm/drivers/video/fbmem.c |   19 +++++++++++++++++++
 1 files changed, 19 insertions(+)

diff -puN drivers/video/fbmem.c~sysfs-for-framebuffer drivers/video/fbmem.c
--- 25/drivers/video/fbmem.c~sysfs-for-framebuffer	2004-03-23 22:59:52.850022104 -0800
+++ 25-akpm/drivers/video/fbmem.c	2004-03-23 22:59:52.853021648 -0800
@@ -32,6 +32,9 @@
 #include <linux/kmod.h>
 #endif
 #include <linux/devfs_fs_kernel.h>
+#include <linux/err.h>
+#include <linux/kernel.h>
+#include <linux/device.h>
 
 #if defined(__mc68000__) || defined(CONFIG_APUS)
 #include <asm/setup.h>
@@ -1249,6 +1252,8 @@ static struct file_operations fb_fops = 
 #endif
 };
 
+static struct class_simple *fb_class;
+
 /**
  *	register_framebuffer - registers a frame buffer device
  *	@fb_info: frame buffer info structure
@@ -1263,6 +1268,7 @@ int
 register_framebuffer(struct fb_info *fb_info)
 {
 	int i;
+	struct class_device *c;
 
 	if (num_registered_fb == FB_MAX)
 		return -ENXIO;
@@ -1271,6 +1277,12 @@ register_framebuffer(struct fb_info *fb_
 		if (!registered_fb[i])
 			break;
 	fb_info->node = i;
+
+	c = class_simple_device_add(fb_class, MKDEV(FB_MAJOR, i), NULL, "fb%d", i);
+	if (IS_ERR(c)) {
+		/* Not fatal */
+		printk(KERN_WARNING "Unable to create class_device for framebuffer %d; errno = %ld\n", i, PTR_ERR(c));
+	}
 	
 	if (fb_info->pixmap.addr == NULL) {
 		fb_info->pixmap.addr = kmalloc(FBPIXMAPSIZE, GFP_KERNEL);
@@ -1336,6 +1348,7 @@ unregister_framebuffer(struct fb_info *f
 		kfree(fb_info->sprite.addr);
 	registered_fb[i]=NULL;
 	num_registered_fb--;
+	class_simple_device_remove(MKDEV(FB_MAJOR, i));
 	return 0;
 }
 
@@ -1397,6 +1410,12 @@ fbmem_init(void)
 	if (register_chrdev(FB_MAJOR,"fb",&fb_fops))
 		printk("unable to get major %d for fb devs\n", FB_MAJOR);
 
+	fb_class = class_simple_create(THIS_MODULE, "graphics");
+	if (IS_ERR(fb_class)) {
+		printk(KERN_WARNING "Unable to create fb class; errno = %ld\n", PTR_ERR(fb_class));
+		fb_class = NULL;
+	}
+
 #ifdef CONFIG_FB_OF
 	if (ofonly) {
 		offb_init();

_
